==> qtjambi-uic-5.15.19-sources.jar: io/qt/uic/ui4/DomBrush.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomBrush</code></p>
 */
public class DomBrush extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <code>DomBrush::Kind</code></p>
     * @hidden
     */
    public enum Kind implements QtEnumerator {
        /**
         * <p>Representing <code>DomBrush::<wbr/>Unknown</code></p>
         */
        Unknown(0),
        /**
         * <p>Representing <code>DomBrush::<wbr/>Color</code></p>
         */
        Color(1),
        /**
         * <p>Representing <code>DomBrush::<wbr/>Texture</code></p>
         */
        Texture(2),
        /**
         * <p>Representing <code>DomBrush::<wbr/>Gradient</code></p>
         */
        Gradient(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Color;
            case 2: return Texture;
            case 3: return Gradient;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>DomBrush::<wbr/>DomBrush()</code></p>
     */
    public DomBrush(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomBrush instance);
    
    /**
     * <p>See <code>DomBrush::<wbr/>attributeBrushStyle()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeBrushStyle(){
        return attributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeBrushStyle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>clearAttributeBrushStyle()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeBrushStyle(){
        clearAttributeBrushStyle_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeBrushStyle_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>elementColor()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColor elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColor elementColor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>elementGradient()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomGradient elementGradient(){
        return elementGradient_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomGradient elementGradient_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>elementTexture()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomProperty elementTexture(){
        return elementTexture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomProperty elementTexture_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>hasAttributeBrushStyle()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeBrushStyle(){
        return hasAttributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeBrushStyle_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>kind()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.DomBrush.@NonNull Kind kind(){
        return io.qt.uic.ui4.DomBrush.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomBrush::<wbr/>setAttributeBrushStyle(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeBrushStyle(java.lang.@NonNull String a){
        setAttributeBrushStyle_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeBrushStyle_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomBrush::<wbr/>setElementColor(DomColor*)</code></p>
     */
    @QtUninvokable
    public final void setElementColor(io.qt.uic.ui4.@Nullable DomColor a){
        setElementColor_native_DomColor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementColor_native_DomColor_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomBrush::<wbr/>setElementGradient(DomGradient*)</code></p>
     */
    @QtUninvokable
    public final void setElementGradient(io.qt.uic.ui4.@Nullable DomGradient a){
        setElementGradient_native_DomGradient_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementGradient_native_DomGradient_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomBrush::<wbr/>setElementTexture(DomProperty*)</code></p>
     */
    @QtUninvokable
    public final void setElementTexture(io.qt.uic.ui4.@Nullable DomProperty a){
        setElementTexture_native_DomProperty_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementTexture_native_DomProperty_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomBrush::<wbr/>takeElementColor()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColor takeElementColor(){
        return takeElementColor_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColor takeElementColor_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>takeElementGradient()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomGradient takeElementGradient(){
        return takeElementGradient_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomGradient takeElementGradient_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>takeElementTexture()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomProperty takeElementTexture(){
        return takeElementTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomProperty takeElementTexture_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomBrush::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomBrush(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.12-sources.jar: io/qt/uic/ui4/DomBrush.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomBrush</p>
 */
public class DomBrush extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum DomBrush::Kind</p>
     */
    public enum Kind implements QtEnumerator {
        Unknown(0),
        Color(1),
        Texture(2),
        Gradient(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Kind(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static Kind resolve(int value) {
            switch (value) {
            case 0: return Unknown;
            case 1: return Color;
            case 2: return Texture;
            case 3: return Gradient;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public DomBrush(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomBrush instance);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeBrushStyle(){
        return attributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeBrushStyle_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeBrushStyle(){
        clearAttributeBrushStyle_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeBrushStyle_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColor elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColor elementColor_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomGradient elementGradient(){
        return elementGradient_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomGradient elementGradient_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomProperty elementTexture(){
        return elementTexture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomProperty elementTexture_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeBrushStyle(){
        return hasAttributeBrushStyle_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeBrushStyle_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.DomBrush.@NonNull Kind kind(){
        return io.qt.uic.ui4.DomBrush.Kind.resolve(kind_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int kind_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setAttributeBrushStyle(java.lang.@NonNull String a){
        setAttributeBrushStyle_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeBrushStyle_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @QtUninvokable
    public final void setElementColor(io.qt.uic.ui4.@Nullable DomColor a){
        setElementColor_native_DomColor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementColor_native_DomColor_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementGradient(io.qt.uic.ui4.@Nullable DomGradient a){
        setElementGradient_native_DomGradient_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementGradient_native_DomGradient_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementTexture(io.qt.uic.ui4.@Nullable DomProperty a){
        setElementTexture_native_DomProperty_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementTexture_native_DomProperty_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColor takeElementColor(){
        return takeElementColor_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColor takeElementColor_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomGradient takeElementGradient(){
        return takeElementGradient_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomGradient takeElementGradient_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomProperty takeElementTexture(){
        return takeElementTexture_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomProperty takeElementTexture_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomBrush(QPrivateConstructor p) { super(p); } 
    
}
